<?php

use EventPortal\Domain\Component\Button;
use EventPortal\Domain\Component\ButtonDropdown;
use EventPortal\Domain\Component\Column\TextColumn;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Speaker\Models\Speaker;
use EventPortal\Domain\Table\Facades\Table;
use EventPortal\Enums\InertiaMethod;
use Illuminate\Database\Eloquent\Builder;

Table::make('event-speaker.index')
    ->setColumns(function () {
        return [
            TextColumn::make('First name')->default()->sortable(),
            TextColumn::make('Last name')->default()->sortable(),
            TextColumn::make('Email')->default()->sortable(),
            TextColumn::make('Profession')->sortable(),
        ];
    })
    ->setRowAction(function (Event $event, Speaker $speaker) {
        return ButtonDropdown::make('Manage speaker')
            ->actions([
                Button::make('View')
                    ->method(InertiaMethod::VISIT())
                    ->route('admin.event.speaker.show', [
                        'event' => $event->id,
                        'speaker' => $speaker->id,
                    ]),
            ]);
    });

Table::make('event-speaker.add')
    ->tapQuery(function (Builder $query) {
        return $query->joinRelationship('user');
    })
    ->setColumns(function () {
        return [
            TextColumn::make('First name')->default()->sortable(),
            TextColumn::make('Last name')->default()->sortable(),
            TextColumn::make('Email')->default()->sortable(),
            TextColumn::make('Profession')->sortable(),
        ];
    })
    ->addGlobalAction(function (Event $event) {
        return Button::make('Add speakers to event')
            ->method(InertiaMethod::POST())
            ->route('admin.event.speaker.store', [
                'event' => $event->id,
            ]);
    });
