<?php

namespace EventPortal\Tests\Unit\Form;

use EventPortal\Domain\Delegate\Models\Delegate;
use EventPortal\Domain\Delegate\Models\DelegateFormData;
use EventPortal\Domain\Delegate\Models\DelegateFormStep;
use EventPortal\Domain\Event\Form\Enums\State;
use EventPortal\Domain\Event\Form\Models\Form;
use EventPortal\Domain\Event\Form\Models\FormStep;
use EventPortal\Domain\Event\Form\Models\FormStepSection;
use EventPortal\Domain\Event\Form\Models\Question;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Form\DisplayForm;
use EventPortal\Domain\Form\EditForm;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;
use Spatie\Snapshots\MatchesSnapshots;

class EditFormTest extends TestCase
{
    use RefreshDatabase, MatchesSnapshots;

    /** @test **/
    public function get_form_for_edit()
    {
        $event = factory(Event::class)->state('snapshot')->create();
        $delegate = factory(Delegate::class)->state('snapshot')->create();
        $form = factory(Form::class)->state('snapshot')->create();
        $step = factory(FormStep::class)->state('snapshot')->create(['form_id' => $form->id]);
        $section = factory(FormStepSection::class)->state('snapshot')->create(['form_step_id' => $step->id]);
        $question = factory(Question::class)->state('snapshot')->create(['form_step_section_id' => $section->id]);

        factory(DelegateFormStep::class)->create([
            'state' => State::Complete()->getValue(),
            'delegate_id' => $delegate->id,
            'form_step_id' => $step->id,
        ]);

        factory(DelegateFormData::class)->create([
            'delegate_id' => $delegate->id,
            'form_step_id' => $step->id,
            'question_id' => $question->id,
            'value' => 'Hello There!',
        ]);

        $previousStep = null;

        $form = EditForm::make()
            ->forEvent($event)
            ->forForm($form)
            ->forDelegate($delegate)
            ->currentStep($step)
            ->previousStep($previousStep)
            ->render();

        $this->assertMatchesJsonSnapshot($form);
    }
}
